bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 3. Aventiure
___________________________________________________ #### Auentv wie Sivrit ze Wormze chome
| ### DEn herren mvten selten deheiniv hercenleit ### er horte sagen mære wie ein schoniv meit ### in Burgonden wære ze wnsche wolgetan ### davon er sit vil arebeit vn– ovch frevden gewan
###### 45 | ### Div ir vnmazen schone was vil witen chunt ### vn– ir vil hochgemvte zv der selben stunt ### an der iunchfrowen so manic helt ervant ### ez ladete vil der geste in daz Gvntheres lant
###### 46 | ### Swaz man nach ir minne der <werbenden> sach ### Chriemhilt in ir sinne ir selber nie veriach ### daz si deheinen wolde zeime trvte han ### er was ir noch vil vremde dem si wart sider vndertan
| ### Do gedaht vf hohe minne daz Sigelinde chint ### ez was ir aller werben wider in ein wint ### er mohte wol verdienen schoner frowen lip ### sit wart div edel Chriemh' des starchen Sifrides wip
###### 48 | ### Im rieten sine mage vn– genvge sine man ### sit daz er vf minne vlizzen sich began ### daz er eine næme div im mohte zemen ### do sprach der herre Sifrit so wil ich Chriemh' nemen
###### 49 | ### die edeln iuncfrowen vz Burgonden lant ### durch ir vil grozen schone von sage ist mir bechant ### nie keiser wart so riche der wolde haben wip ### im enzæme wol ze minnen der iungen kuniginne lip
###### 50 | ### Disiv selben mære vernam do Sigemvnt ### ez [3r]reite sin gesinde da uon wart im chunt ### der wille sines kindes was im grimme leit ### daz er werben wolde die vil herlichen meit
###### 51 | ### Ez gefriesch ovch Sigelint des edeln kuniges wip ### si hete grozze sorge vmbe ir kindes lip ### den vorhte si verliesen von Gunthers man ### den gewerp man do dem degene sere leiden began
| ### Do sprach der starche Sivrit vil lieber vater min ### ane edeler frowen minne wolde ich immer sin ### ich enwrbe dar min herce vil groze liebe hat ### swaz ieman reden chunde des ist deheiner slahte rat
###### 53 | ### Sit dv niht wil erwinden sprach der kunic do ### so bin ich dines willen inneklichen vro ### vn– wil dirz helfen fugen so ich beste chan ### doch hat der chunic Gvnther vil manigen vbermvten man
###### 54 | ### Ob ez ander niemen wære wan Hagene der degen ### der chan mit vbermvte der hochverte pflegen ### daz ich vil sere fvrhte deiz vns werde leit ### ia ist mir solher mære dicke vil von in geseit
###### 55 | ### Was mag vns daz gewerren sprach do Sifrit ### swaz ich friwentliche niht ab in erbit ### daz mac doch mit ellen erwerben wol min hant ### ich trow im an ertwingen bediv lvt vn– lant
| ### Do sprach der furste Sigemvnt din rede div ist mir leit ### wan wrden disiv mære ze Rine geseit ### dvne dorftes nimmer geriten in daz lant ### Gunther vn– Gernot sint mir lange wol bekant
###### 57 | ### Mit gewalt niemen erwerben mac die meit ### so sprach der kunic Sigemvnt daz ist mir wol geseit ### wellen aber wir mit rechen riten in daz lant ### vnsern besten friwenden sol div reise sin bechant
###### 58 | ### Des enist mir niht ze mvote sprach do Sifrit ### daz mir svln rechen ze Rine volgen mit ### durch deheine hervart daz were mir leit ### da mit ich solde ertwingen die vil herlichen meit
###### 59 | ### Si mac svs wol erwerben da min eines hant ### ich wil mit zwelf gesellen in Gunthers lant ### dar sult ir mir helfen vater Sigemunt ### do gap man sinen degenen ze kleiden gra vn– punt
| ### Do vernam ovch disiv mære sin mvter Sigelint ### si begunde trvren vmbe ir liebez kint ### ia vorhte si vil sere die Guntheres man ### div edele kuniginne darvmbe weinen began
###### 61 | ### Do chom der herre Sivrit da er die frowen sach ### wider sine mvter gvetlicher sprach ### irn svlt niht weinen durch den willen min ### ia wil ich ane sorge vor allen wiganden sin
###### 62 | ### Nv helfet mir der reise in Burgonden lant ### daz ich un– mine rechen haben solch gewant ### daz so stolze degene mit eren mvgen tragen ### des wil ich genade iv mit triwen immer sagen
###### 63 | ### Sit dv niht wil erwinden sprach do Sigelint ### so hilf ich dir der reise min einigez kint ### mit der besten wæte die ritter ie getrvoch ### dir vn– den dinen degenen ir sult ir furen genvoch
| ### Des neig ir mit zvhten der vil chvne man ### er sprach ich wil <zer verte> niemen mere han ### niwan zwelf gesellen [3v]den sol man prufen wat ### ich wil versvchen gerne wie ez vmbe Chriemhilde stat
###### 65 | ### Da sazen schone frowe naht un– tac ### luzzil deheiner mvoze ir deheiniv pflach ### vnze si geworhten die Sifrides wat ### er wolde siner verte han deheiner slahte rat
###### 66 | ### Sin vater hiez im zieren sin ritterlich gewant ### da mit er varn wolde in Burgonden lant ### die ir uil liehten brunne die wrden ovch bereit ### vn– ir vil gvten helme ir <schilde> schon vn– breit
###### 67 | ### Do nahet int ir reise zen Burgonden dan ### si heten vmbe ir sorge wiez im solde ergan ### ob si immer wider solden chomen in daz lant ### do svomte man den degenen von dannen waffen vn– gewant
###### 68 | ### Ir rosse div warn schone ir gereite goldes rot ### lebt iemen vbermvter des enwas niht not ### denne wære Sivrit vn– die sine man ### wie schone er vrlovbes gerte zen Burgonden dan
| ### In werte trvorechliche der kunic vn– ovch sin wip ### er troste minneklichen do ir beider lip ### er sprach ir sult niht weinen durch den willen min ### immer ane sorge mvget ir wol mines libes sin
###### 70 | ### Ez was leit den rechen ez weint ovch manic meit ### ich wæn in hete rehte ir herce daz geseit ### daz in so vil ir friwende da von gelege tot ### von schulden si do klageten des gie in endeliche not
###### 71 | ### An dem sehsten morgen ze Wormze vf den sant ### riten die vil chunen allez ir gewant ### was uon rotem golde ir gereite wol getan ### ir ross div giengen ebene des herren Sifrides man
###### 72 | ### Ir schilde warn niwe starc vn– breit ### vn– lieht ir helme da ze hove reit ### Sifrit der vil chune in Guntheres lant ### man gesach an heleden nie so herlich gewant
| ### Div ort der swerte giengen nider vf die sporn ### ez furten scharpfe geren die ritter vz erchorn ### Sivrit der furt ir einen wol zweier spannen breit ### der ze sinen ekken harte vreislichen sneit
###### 74 | ### Die goldes roten zevme furtens an der hant ### von siden furgebuge sus <chomens> in daz lant ### daz volch si allenthalben kapfen an began ### do liefen in engegene des kunic Guntheres man
###### 75 | ### Die hochgemvten rechen ritter vn– knehte ### die sprungen in begegene daz was michel reht ### vn– enpfiengen dise geste in ir herren lant ### si namen in die moere vn– ir schilde von der hant
###### 76 | ### Div ross si wolden dannen ziehen an ir gemach ### Sifrit der starche zv den helden sprach ### lat uns noch die moere eine wile stan ### wir wellen schiere hinnen des ich gvten willen han
###### 77 | ### Man sol ovch unser schilde ninder von uns tragen ### wa ich den kunic uinde kan mir daz iemen sagen ### Gunthern den richen vz Burgonden lant ### do sagetez im ir einer dem iz rehte was bekant
| ### Welt ir den kunic uinden daz mac vil wol geschehen ### vf ienem sal witen han ich <in> gesehen ### bi den sinen degenen welt ir zv zim gan ### ir mvget da vor [4r]im vinden manigen vz erwelten man
###### 79 | ### Do waren ovch dem kunige div mære nv geseit ### daz vf sinem hofe wæren ritter vil gemeit ### die furten liehte brunne vn– herlich gewant ### si enkande niemen in der Burgonden lant
###### 80 | ### Den wirt des hete wnder von wanne koemen dar ### die herliche rechen in wæte lieht gevar ### un– mit so schonen schilden niwe un– breit ### daz im daz niemen sagete daz was im groezliche leit
###### 81 | ### Des antwrte ein reche der hiez Ortwin ### starch un– chvone mohter wol sin ### Sit wir ir niht erchennen so sult ir heizen gan ### nach mime hoheim Hagene den sul wir si sehen lan
###### 82 | ### Dem sint kunt div riche vn– ovch div fremden lant ### mager si bekennen daz tvot er uns bechant ### in hiez der chunic bringen mit den sinen man ### sach man in zvhtekliche ze hofe fur den chunic gan
###### 83 | ### Waz sin der kunic wolde des vragete Hagene ### ez sint in mime huse vremde degene ### die niemen hie bekennet ob ir si ê gesehen ### habt in vremden landen des svlt ir Hagene mir veriehen
###### 84 | ### Das tvn ich <sicherlichen> zeinem venster er do gie ### sin ovge er do wenchen zv den gesten lie ### wol behagete im ir geverte vn– ovch ir gewant ### si warn im vil vremde in der Burgonden lant
| ### Er sprach von swannen furen die rechen an den Rin ### ez mohten selbe fursten oder fursten boten sin ### ir ross div sint so schone ir chleider harte gvot ### swannen si ioch riten si sint vil hohe gemvot
###### 86 | ### Also sprach do Hagene als ich mich kan verstan ### swie ich Sifriden noh nie gesehen han ### so wil ich wol getrowen swie ez sich gefuget hat ### so ist ez der reche der dort so herlichen stat
###### 87 | ### Er bringet niwe mære her in dizze lant ### die chvnen Nibelunge slvch des heldes hant ### Schilbunc vn– Nibelunch div richen kuniges chint ### er frumte starchiv wnder mit siner grozen chrefte sint
###### 88 | ### Da der helt aleine an alle helfe reit ### er vant vor einem berge daz ist mir wol geseit ### bi Nibelunges horde vil manigen kunen man ### die warn im ê fremde vnz er ir chunde da gewan
| ### Hort der Nibelunges der was gar getragen ### vz einem holn berge nv horet wnder sagen ### wie in teilen wolden der Nibelunge man ### daz sach der degen Sifrit den helt es wndern began
###### 90 | ### Er chom zv zin so nahen daz er die rechen sach ### vn ovch in die <degene> ir einer drunder sprach ### hie chumt der starch Sivrit der helt von Niderlant ### vil seltseniv mære er an den Nibelungen vant
###### 91 | ### Den rechen wol enpfiengen Schilbunc vn– <Nibelunch> ### mie gemeinem site die edeln fursten iunch ### den schaz in baten teilen den vil chunen man ### vn– batens in so lange vnz er inz loben began
###### 92 | ### Er sach so vil gesteines als wir horen sagen ### hundert chantzwægene ez mohten niht getragen ### noch [4v]me des roten goldes von Nibelunge lant ### daz solde in allez teilen des chunen Sifrides hant
###### 93 | ### Do gaben si im ze miete daz Nibelunges swert ### si wrden mit dem dienste vil vbele gewert ### den in da leisten solde der vil chune man ### ern kundes niht verenden do wart der helt von in bestan
| ### Den schatz er vngeteilet beliben mvse lan ### do begunden mit im striten der zweier kunige man ### mit ir vater swerte daz Palmvnch was genant ### ez streit ab in der chune den hort vn– Nibelung lant
###### 95 | ### Si heten da ir friunde zwelf chune man ### die starch als risen warn waz chundez si vervan ### die slvoch sit mit zorne div Sifrides hant ### vn– rechen sibenhundert dwanger von Nibelunge lant
###### 96 | ### Dar zv die richen kunige die sluger beide tot ### er chom von Albriche sit in groze not ### der wande sine herren rechen da zehant ### vnz er die grozen sterche sit an Sifride vant
###### 97 | ### Done chunde im gestriten daz starche getwerch ### alsam die lewen wilde si liefen an den berch ### da er die tarnkappen Albrichæ ane gewan ### do wart des hordes herre Sifrit der vil chune man
| ### Die da getorsten striten die lagen alle erslagen ### den schatz hiez er do balde furen vn– tragen ### da in ê da namen die Nibelunges man ### Albrich der vil starche do die kameren gewan
###### 99 | ### Er mvos im swern eide er dient im so sin kneht ### aller hande dienste was er im gereht ### so sprach von Tronege Hagene daz hat er getan ### also grozer chrefte nimere reche gewan
###### 100 | ### Noch weiz ich an im mere daz mir ist bekant ### einen lintrachen sluoch des heledes hant ### do badet er in dem blvote des ist der helt gemeit ### von also vester hvte daz in nie wafen sit versneit
###### 101 | ### Nv svln wir den rechen enpfahen deste baz ### daz wir iht verdienen den sinen starchen haz ### sin lip der ist so chune man sol in holden han ### er hat mit sinen ellen so mænigiv wnder getan
| ### Do sprach der chunich riche dv maht wol haben war ### nv sich wie degenliche er stet gein strites var ### er unt die sine degene der wnderchune man ### wir suln im begegene hin nider zv dem rechen gan
###### 103 | ### Daz mvgt ir sprach do Hagene wol mit eren tvn ### er ist von hohem chunne eines richen kuniges svn ### er stet in der gebære mich dunchet wizze christ ### ez ensin niht kleiniv mære darvmbe er her geriten ist
###### 104 | ### Do sprach der wirt des landes nv si vns willechomen ### er ist edel un– chvone daz han ich wol vernomen ### des sol ovch er geniezen in Burgonden lant ### do gie der chunic Gunther da er Sifriden vant
###### 105 | ### Der wirt vn– sine rechen enpfiengen so den gast ### daz in an ir zvhten wenich iht gebrast ### des begunde in nigen der vil chune man ### man sah in zvhtekliche mit den sinen rechen stan
| ### Mich wndert [5r]dirre mære sprach der wirt zehant ### von wanne ir edel Sifrit sit chomen in daz lant ### oder waz ir werbet ze Wormez an den Rin ### do sprach der gast zem kunige daz sol ivch vnverdaget sin
###### 107 | ### Mir wart gesaget mære in mins vater lant ### daz hie bi iv wæren daz het ich gern <erkant> ### die chunsten rechen des han ich vil vernomen ### die ie kunic gewnne dar vmbe bin ich her bechomen
###### 108 | ### Ovch hort ich iv selben der degenheite iehen ### daz man kunic deheinen chuner habe gesehen ### des giht iv vil der lute vber elliv disiv lant ### nvne wil ich niht erwinden vnz ez mir werde bechant
###### 109 | ### Ich bin ovch reche vn– solde chrone tragen ### ich wil daz gern fugen daz si von mir sagen ### daz ich habe von rehte lute vn– lant ### darvmbe sol min ere vn– min hovbt wesen pfant
###### 110 | ### Nv ir sit so chune als mir ist geseit ### iane rvche ich ist iemen liep oder leit ### ich wil an iv ertwingen swaz ir mugt han ### lant vn– burge daz sol mir wesen allez undertan
| ### Den chunic hete wnder vn– sine man allesam ### vmbe disiv mære die er hie vernam ### daz er des hete willen er næme im siniv lant ### daz horten sine degene do wart in zvernen bechant
###### 112 | ### Wie hete ich daz verdienet sprach Gunther der degen ### des min vater lange mit eren hat gepflegen ### daz wir daz solden vliesen von iemannes kraft ### wir liezen vbel schinen daz ovch wir pflegen ritterschaft
###### 113 | ### Ich enwil es niht erwinden sprach aber der chune man ### ez enmvge von dinem ellen din lant den vride han ### ich wils alles walten vn– ovch div erbe min ### erwirbestvz mit ellen die svln von rehte wesen din
###### 114 | ### Din lant vn– ovch daz mine suln geliche ligen ### sweder unser einer am andern mac gesigen ### dem sol ez allez dienen die lute vn– ovch div lant ### da widerredet aleine der herre Gernot zehant
###### 115 | ### Wir han des niht gedingen sprach do Gernot ### daz wir iht lande irtwingen daz iemen drumbe tot ### gelige vor rechen handen wir haben richiv lant ### div dienent vns von rehte ze nieman sint si baz bewant
| ### <In> vil grimmem mvote da stunden die friunde sin ### do was ovch dar vnder der herre Ortwin ### der sprach disiv svone ist mir von hercen leit ### iv hat der starche Sifrit vnverdienet widerseit
###### 117 | ### Ob ir vn– iwer bruder hetet niht die wer ### vn– ob er danne furte ein michil kuniges her ### ich trwote wol erstriten daz der chune man ### die grozen vbermvete von warn schulden mvse lan
###### 118 | ### Daz zvrnde harte sere der helt von Niderlant ### sich ensol niht vermezzen wider mich din hant ### ich bin ein kunic riche so bistv kuniges man ### ia enzimt dir niht mit strite deheinen minen genoz bestan
###### 119 | ### Nach swerten rief do sere von Metzen Ortwin ### er mohte Hagenen swester suon von Tronege vil [5v]wol sin ### daz der so lange dagete daz was dem kunige leit ### do vnderstundez Gernot der ritter <kvone> vn– gemeit
###### 120 | ### Er sprach ze Ortwine lat iwer zvrnen stan ### vns en hat herre Sifrit solhes niht getan ### wir mugen ez noch wol scheiden mit zvhten dest min rat ### vn– haben in ze frivnde daz uns lobelicher stat
###### 121 | ### Des antwrte Hagene vns mac wol wesen leit ### allen iwern degenen daz er ie gereit ### durch striten her ze Rine er soldez haben lan ### im heten min herren solher leide niht getan
| ### Do sprach aber Sifrit der chreftige man ### mvte ivch daz her Hagene daz ich gesprochen han ### so sol ich lazen chiesen daz die hende min ### wellent vil gewaldech hie zen Burgonden sin
###### 123 | ### Daz sol ich eine wenden sprach do Gernot ### allen sinen degenen reden er verbot ### iht mit vbermvete des im wære leit ### do gedaht ovch Sifrit an die vil herlichen meit
###### 124 | ### Wie zæme vns mit iv striten sprach aber Gernot ### swaz helde nv dar under mvsen ligen tot ### wir hetens luzzil ere ob wir ez wolden tvon ### des antwrt Sifrit des kunic Sigemundes sun
###### 125 | ### Warumbe bitet Hagene vn– ovch Ortwin ### daz er niht gahet striten mie den frivnden sin ### der er also manigen hie ze lande hat ### si mvsin rede vermiden daz was Gernotes rat
###### 126 | ### Ir sult vns wesen willechomen sprach Giselher daz kint ### vn– iwer hergesellen die hie mit iv sint ### wir suln iv gerne dienen ich un– die mage min ### do hiez man den gesten schenchen Guntheres win
| ### Do sprach der wirt des landes allez daz wir han ### gervchet irs nach eren daz si iv vndertan ### vn– si mit iv geteilet lip un– gvot ### do wart der herre Siurit ein luzzel senfter gemvot
###### 128 | ### Do hiez man in behalten alliz ir gewant ### man gab in herberge die besten die man vant ### Sivrides knappen man schvof in gvot gemach ### den gast man sit vil gerne da zen Buregonden sach
###### 129 | ### Man bot im michel ere darnach ze manigen tagen ### tusint stunden mere danne ich iv kunde gesagen ### daz hete verscholt sin ellen ir svlt wol wizzen daz ### in sach vil luzzil iemen der im were gehaz
###### 130 | ### Sich vlizzen kurzewile die kunige vn– ovch ir man ### so was er ie der beste swes man da began ### des chunde im volgen niemen so michel was sin kraft ### so si den stein wrfen oder schuzzen den schaft
###### 131 | ### Swa so vor den frowen durch ir hofscheit ### churzewile pflagen die ritter vil gemeit ### da sah man ie vil gern den helt vz Niderlant ### er het vf hohe minne sine sinne gewant
| ### Ze hofe die schonen frowen vrageten mêre ### wer der stolze vremde reche wêre ### sin lip der ist so schone vil riche sin gewant ### do sprachen ir genvge ez ist der chunic von Niderlant
###### 133 | ### Swes iemen da begunde des was sin lip bereit ### [6r]er trvoch in sinem mvte ein minnekliche meit ### vn– ovch in ein div frowe die er noch niene gesach ### div im in heinliche vil dicke gvtliche sprach
###### 134 | ### Swenne vofem hofe wolde spilen da div kint ### ritter vn– knappen daz sach vil diche sint ### Criemh' durch div venster div kuniginne her ### deheiner kurzewile bedorfte div kuniginne mer
###### 135 | ### Vn– wesser daz in sehe die er in hercen trvoch ### da het er kurcewile immer ane genvoch ### solt ovoch er si sehen ir sult gelovben daz ### daz im in dirre werlde chunde nimmer werden baz
| ### Swenner bi den rechen vf dem hofe stvnt ### also noch die lute durch kurzewile tvont ### so stvnt so minnekliche daz Sigelinde chint ### daz in dvrch hercenliebe trvtte manic frowe sint
###### 137 | ### Er daht ovch manige zite wie sol daz geschehen ### daz ich die maget edele mit ovgen mvge gesehen ### die ich von hercen minne vn– lange han getan ### div ist mir vil vremde des mvz ich dicke truric stan
###### 138 | ### Swenne die kunige riche riten in ir lant ### so mvsin ie die rechen mit in al zehant ### da mit reit ovch Sifrit daz was den frowen leit ### er het durch hohe minne diche michel arebeit
###### 139 | ### Svs wonter bi den herren daz ist al war ### in Guntheres lande volleklich ein iar ### daz er die minneklichen die zite niene gesach ### von der im sit vil liebe vn– ovch vil leide geschach

<<< Übersicht <<< vorige Seite nächste Seite >>>